@@ -335,3 +335,34 @@ SimchatTorahEve = Holiday(
     "Simchat Torah Eve", month=1, day=1, offset=[_SimchatTorah(), Day(-1)]
 )
 SimchatTorah = Holiday("Simchat Torah", month=1, day=1, offset=[_SimchatTorah()])
+
+# Passover interim days are the days between beginning and end of passover. Any otherwise regular business day in that
+# period becomes an early close day.
+PassoverInterimDay1 = Holiday(
+    "Passover Interim Day",
+    month=1,
+    day=1,
+    offset=[_Passover(), Day(1)],
+    days_of_week=(0, 1, 2, 3, 6),
+)
+PassoverInterimDay2 = Holiday(
+    "Passover Interim Day",
+    month=1,
+    day=1,
+    offset=[_Passover(), Day(2)],
+    days_of_week=(0, 1, 2, 3, 6),
+)
+PassoverInterimDay3 = Holiday(
+    "Passover Interim Day",
+    month=1,
+    day=1,
+    offset=[_Passover(), Day(3)],
+    days_of_week=(0, 1, 2, 3, 6),
+)
+PassoverInterimDay4 = Holiday(
+    "Passover Interim Day",
+    month=1,
+    day=1,
+    offset=[_Passover(), Day(4)],
+    days_of_week=(0, 1, 2, 3, 6),
+)
