@@ -7,7 +7,8 @@ from .pandas_extensions.korean_holiday import (
     KoreanSolarHoliday,
     KoreanLunarHoliday,
     alternative_holiday,
-    childrens_day_alternative_holiday,
+    alternative_holiday_for_seollal_and_chuseok,
+    alternative_holiday_for_childrens_day,
     last_business_day,
 )
 
@@ -1079,10 +1080,25 @@ dumped_precomputed_krx_holidays = pd.to_datetime(
         "2021-03-01",
         "2021-05-05",
         "2021-05-19",
+        "2021-08-16",
         "2021-09-20",
         "2021-09-21",
         "2021-09-22",
+        "2021-10-04",
+        "2021-10-11",
         "2021-12-31",
+        "2022-01-31",
+        "2022-02-01",
+        "2022-02-02",
+        "2022-03-01",
+        "2022-05-05",
+        "2022-06-06",
+        "2022-08-15",
+        "2022-09-09",
+        "2022-09-12",
+        "2022-10-03",
+        "2022-10-10",
+        "2022-12-30",
     ]
 )
 
@@ -1116,14 +1132,14 @@ SeollalBefore = KoreanLunarHoliday(
     month=1,
     day=1,
     offset=Day(-1),
-    observance=alternative_holiday,
+    observance=alternative_holiday_for_seollal_and_chuseok,
     start_date=pd.Timestamp("1989-01-01"),
 )  # Seollal gained additional before/after holidays since 1989
 Seollal = KoreanLunarHoliday(
     "Seollal (New Year's Day by the lunar)",
     month=1,
     day=1,
-    observance=alternative_holiday,
+    observance=alternative_holiday_for_seollal_and_chuseok,
     start_date=pd.Timestamp("1985-01-01"),
 )  # Seollal newly became holiday since 1985
 SeollalAfter = KoreanLunarHoliday(
@@ -1131,11 +1147,11 @@ SeollalAfter = KoreanLunarHoliday(
     month=1,
     day=1,
     offset=Day(1),
-    observance=alternative_holiday,
+    observance=alternative_holiday_for_seollal_and_chuseok,
     start_date=pd.Timestamp("1989-01-01"),
 )  # Seollal gained additional before/after holidays since 1989
 IndependenceMovementDay = KoreanSolarHoliday(
-    "Independence Movement Day", month=3, day=1
+    "Independence Movement Day", month=3, day=1, observance=alternative_holiday
 )
 ArborDay = KoreanSolarHoliday(
     "Arbor Day",
@@ -1152,7 +1168,7 @@ LoborDay = KoreanSolarHoliday(
     "Labor Day", month=5, day=1, start_date=pd.Timestamp("1994-01-01")
 )  # Labor day changed it's day from 03/10 to 05/01 since 1994
 ChildrensDay = KoreanSolarHoliday(
-    "Children's Day", month=5, day=5, observance=childrens_day_alternative_holiday
+    "Children's Day", month=5, day=5, observance=alternative_holiday_for_childrens_day
 )
 MemorialDay = KoreanSolarHoliday("Memorial Day", month=6, day=6)
 ConstitutionDay = KoreanSolarHoliday(
@@ -1162,20 +1178,22 @@ ConstitutionDay = KoreanSolarHoliday(
     start_date=pd.Timestamp("1949-10-01"),
     end_date=pd.Timestamp("2007-12-31"),
 )  # Constitution day was holiday from 1949 to 2007
-NationalLiberationDay = KoreanSolarHoliday("National Liberation Day", month=8, day=15)
+NationalLiberationDay = KoreanSolarHoliday(
+    "National Liberation Day", month=8, day=15, observance=alternative_holiday
+)
 ChuseokBefore = KoreanLunarHoliday(
     "Chuseok (Korean Thanksgiving Day) (-1 day)",
     month=8,
     day=15,
     offset=Day(-1),
-    observance=alternative_holiday,
+    observance=alternative_holiday_for_seollal_and_chuseok,
     start_date=pd.Timestamp("1989-01-01"),
 )  # Chuseok gained additional before holiday since 1989, along with Seollal
 Chuseok = KoreanLunarHoliday(
     "Chuseok (Korean Thanksgiving Day)",
     month=8,
     day=15,
-    observance=alternative_holiday,
+    observance=alternative_holiday_for_seollal_and_chuseok,
     start_date=pd.Timestamp("1949-01-01"),
 )  # Chuseok originally had no before/after holidays
 ChuseokAfter = KoreanLunarHoliday(
@@ -1183,7 +1201,7 @@ ChuseokAfter = KoreanLunarHoliday(
     month=8,
     day=15,
     offset=Day(1),
-    observance=alternative_holiday,
+    observance=alternative_holiday_for_seollal_and_chuseok,
     start_date=pd.Timestamp("1986-01-01"),
 )  # Chuseok gained additional following holiday since 1986
 ArmedForcesDay = KoreanSolarHoliday(
@@ -1194,7 +1212,7 @@ ArmedForcesDay = KoreanSolarHoliday(
     end_date=pd.Timestamp("1990-12-31"),
 )  # Armed forces day was holiday from 1976 to 1990
 KoreanNationalFoundationDay = KoreanSolarHoliday(
-    "Korean National Foundation Day", month=10, day=3
+    "Korean National Foundation Day", month=10, day=3, observance=alternative_holiday
 )
 OldHangulProclamationDay = KoreanSolarHoliday(
     "Hangul Proclamation Day",
@@ -1208,6 +1226,7 @@ HangulProclamationDay = KoreanSolarHoliday(
     month=10,
     day=9,
     start_date=pd.Timestamp("2013-01-01"),
+    observance=alternative_holiday,
 )  # Hangeul Day became national holiday again in 2013
 Christmas = KoreanSolarHoliday("Christmas", month=12, day=25)
 
